package com.cqxf.prometheus.alert.api;

import com.cqxf.prometheus.alert.annotations.RequestRestController;
import com.cqxf.prometheus.alert.config.PrometheusAlertProperties;
import com.cqxf.prometheus.alert.entity.alert.PrometheusAlert;
import com.cqxf.prometheus.alert.service.MessageService;
import com.cqxf.prometheus.alert.service.PrometheusAlertService;
import com.cqxf.prometheus.alert.utils.AppContext;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContextAware;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.io.IOException;
import java.util.Optional;

@Slf4j
@RequestRestController("/sms/webhook")
@RequiredArgsConstructor
public class PrometheusAlertController {

    private final PrometheusAlertService prometheusAlertService;
    private final AppContext appContext;
    private final PrometheusAlertProperties props;

    @PostMapping("/send")
    public void send(@RequestBody String alert) throws IOException {
        System.out.println(alert);
        ObjectMapper objectMapper = new ObjectMapper();
        JsonParser parser = objectMapper.createParser(alert);
        prometheusAlertService.send(parser.readValueAs(PrometheusAlert.class));
    }

    @GetMapping("/version")
    public String version() {
        log.info("version: {}", "1.0.0");
        return "1.0.0";
    }

    @GetMapping("/test-send/{service}")
    public String testSend(@PathVariable String service) {
        try {
            Optional<MessageService> serviceOptional = Optional.ofNullable(appContext.getBean(service, MessageService.class));
            MessageService messageService = serviceOptional.orElseThrow(() -> new RuntimeException("没有找到指定的服务"));
            messageService.send(props.getManagers(), "测试发送");
            return "测试发送成功";
        } catch (Exception e) {
            return e.getMessage();
        }
    }
}
