package com.cqxf.prometheus.alert.service.impl;

import com.cqxf.prometheus.alert.entity.message.SendCqxfMessageRequest;
import com.cqxf.prometheus.alert.entity.message.SendCqxfMessageResponse;
import com.cqxf.prometheus.alert.service.MessageService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestTemplate;


/**
 * 重庆消防短信调用
 */
@Component("cqxfSms")
@Slf4j
public class CqxfSmsMessageServiceImpl implements MessageService {

    @Autowired
    private RestTemplate restTemplate;

    @Value("${prometheus-alert.cqxfSms.url}")
    private String url;

    @Override
    public void send(String to, String content) {
        log.info("发送至：{}；消息体：{}", to, content);
        SendCqxfMessageRequest ctx = SendCqxfMessageRequest.builder()
                .phone(to)
                .content(content)
                .remark("资源运维监控")
                .build();
        ParameterizedTypeReference<SendCqxfMessageResponse> responseType = new ParameterizedTypeReference<SendCqxfMessageResponse>() {
        };
        ResponseEntity<SendCqxfMessageResponse> responseEntity = restTemplate.exchange(url, HttpMethod.POST, new HttpEntity<SendCqxfMessageRequest>(ctx), responseType);
        SendCqxfMessageResponse response = responseEntity.getBody();
        log.info("短信接口返回内容，response={}", response);
        if (response == null) {
            log.warn("电话号码{}，短信发送失败！", ctx.getPhone());
        }
        String code = response.getCode();
        if (!"0".equals(code)) {
            log.warn("电话号码{}，短信发送失败！", ctx.getPhone());
        }
    }

    @Override
    public void send(String[] tos, String content) {
        send(String.join("," , tos), content);
    }
}
