package com.cqxf.prometheus.alert.service.impl;

import com.cqxf.prometheus.alert.config.PrometheusAlertProperties;
import com.cqxf.prometheus.alert.entity.alert.Alerts;
import com.cqxf.prometheus.alert.entity.alert.PrometheusAlert;
import com.cqxf.prometheus.alert.service.MessageService;
import com.cqxf.prometheus.alert.service.PrometheusAlertService;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

@Component
public class PrometheusAlertServiceImpl implements PrometheusAlertService, ApplicationContextAware {


    private MessageService messageService;

    private CacheMap cacheMap = new CacheMap();

    @Autowired
    private PrometheusAlertProperties properties;

    @Override
    public void send(PrometheusAlert prometheusAlert) {
        Optional<List<Alerts>> optionalAlerts = Optional.ofNullable(prometheusAlert.getAlerts());
        optionalAlerts.ifPresent(alerts -> {
            alerts.forEach(item -> {
                String instance = item.getLabels().get("instance") + ":" + prometheusAlert.getGroupLabels().get("alertname");
                if (item.isFiring()) {
                    if (!cacheMap.isSend(instance)) {
                        messageService.send(properties.getManagers(), "【"+item.getLabels().get("job") + "】" + item.getAnnotations().getDescription());
                        cacheMap.put(instance, Boolean.TRUE);
                    }
                } else if (item.isResolved()) {
                    if (cacheMap.isSend(instance)) {
                       cacheMap.put(instance, Boolean.FALSE);
                    }
                }
            });
        });
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        this.messageService = applicationContext.getBean(properties.getActiveSmsService(), MessageService.class);
    }

    static class CacheMap extends HashMap<String, Boolean> {

        public boolean isSend(String key) {
            if (containsKey(key)) {
                return get(key);
            }
            return false;
        }


    }
}
